summaryrefslogtreecommitdiffstats
path: root/Lib/test/test_importlib
diff options
context:
space:
mode:
authorBrett Cannon <brett@python.org>2022-10-05 22:00:45 (GMT)
committerGitHub <noreply@github.com>2022-10-05 22:00:45 (GMT)
commitc206e53bb726fa795d10cfb0e8d1d1a1a5d1aaa7 (patch)
tree137f9ccf92283c7d33da6f7cf2b614ebcb9ea2c1 /Lib/test/test_importlib
parent2016bc54a22b83d0ca9174b64257cc7bb67a0916 (diff)
downloadcpython-c206e53bb726fa795d10cfb0e8d1d1a1a5d1aaa7.zip
cpython-c206e53bb726fa795d10cfb0e8d1d1a1a5d1aaa7.tar.gz
cpython-c206e53bb726fa795d10cfb0e8d1d1a1a5d1aaa7.tar.bz2
gh-65961: Raise `DeprecationWarning` when `__package__` differs from `__spec__.parent` (#97879)
Also remove `importlib.util.set_package()` which was already slated for removal. Co-authored-by: Eric Snow <ericsnowcurrently@gmail.com>
Diffstat (limited to 'Lib/test/test_importlib')
-rw-r--r--Lib/test/test_importlib/import_/test___package__.py4
-rw-r--r--Lib/test/test_importlib/test_util.py63
2 files changed, 2 insertions, 65 deletions
diff --git a/Lib/test/test_importlib/test_util.py b/Lib/test/test_importlib/test_util.py
index a62d68f..e70971e 100644
--- a/Lib/test/test_importlib/test_util.py
+++ b/Lib/test/test_importlib/test_util.py
@@ -252,69 +252,6 @@ class ModuleForLoaderTests:
) = util.test_both(ModuleForLoaderTests, util=importlib_util)
-class SetPackageTests:
-
- """Tests for importlib.util.set_package."""
-
- def verify(self, module, expect):
- """Verify the module has the expected value for __package__ after
- passing through set_package."""
- fxn = lambda: module
- wrapped = self.util.set_package(fxn)
- with warnings.catch_warnings():
- warnings.simplefilter('ignore', DeprecationWarning)
- wrapped()
- self.assertTrue(hasattr(module, '__package__'))
- self.assertEqual(expect, module.__package__)
-
- def test_top_level(self):
- # __package__ should be set to the empty string if a top-level module.
- # Implicitly tests when package is set to None.
- module = types.ModuleType('module')
- module.__package__ = None
- self.verify(module, '')
-
- def test_package(self):
- # Test setting __package__ for a package.
- module = types.ModuleType('pkg')
- module.__path__ = ['<path>']
- module.__package__ = None
- self.verify(module, 'pkg')
-
- def test_submodule(self):
- # Test __package__ for a module in a package.
- module = types.ModuleType('pkg.mod')
- module.__package__ = None
- self.verify(module, 'pkg')
-
- def test_setting_if_missing(self):
- # __package__ should be set if it is missing.
- module = types.ModuleType('mod')
- if hasattr(module, '__package__'):
- delattr(module, '__package__')
- self.verify(module, '')
-
- def test_leaving_alone(self):
- # If __package__ is set and not None then leave it alone.
- for value in (True, False):
- module = types.ModuleType('mod')
- module.__package__ = value
- self.verify(module, value)
-
- def test_decorator_attrs(self):
- def fxn(module): pass
- with warnings.catch_warnings():
- warnings.simplefilter('ignore', DeprecationWarning)
- wrapped = self.util.set_package(fxn)
- self.assertEqual(wrapped.__name__, fxn.__name__)
- self.assertEqual(wrapped.__qualname__, fxn.__qualname__)
-
-
-(Frozen_SetPackageTests,
- Source_SetPackageTests
- ) = util.test_both(SetPackageTests, util=importlib_util)
-
-
class SetLoaderTests:
"""Tests importlib.util.set_loader()."""
diff --git a/Lib/test/test_importlib/import_/test___package__.py b/Lib/test/test_importlib/import_/test___package__.py
index 1ab5018..ab1b35e 100644
--- a/Lib/test/test_importlib/import_/test___package__.py
+++ b/Lib/test/test_importlib/import_/test___package__.py
@@ -74,8 +74,8 @@ class Using__package__:
self.assertEqual(module.__name__, 'pkg')
def test_warn_when_package_and_spec_disagree(self):
- # Raise an ImportWarning if __package__ != __spec__.parent.
- with self.assertWarns(ImportWarning):
+ # Raise a DeprecationWarning if __package__ != __spec__.parent.
+ with self.assertWarns(DeprecationWarning):
self.import_module({'__package__': 'pkg.fake',
'__spec__': FakeSpec('pkg.fakefake')})